@@ -715,6 +715,8 @@ SQLRETURN MADB_DbcConnectDB(MADB_Dbc *Connection,
       }
     }
 
+  MADB_SetCapabilities(Connection, mysql_get_server_version(Connection->mariadb));
+
   goto end;
 
 err:
@@ -882,7 +884,7 @@ SQLRETURN MADB_DbcGetInfo(MADB_Dbc *Dbc, SQLUSMALLINT InfoType, SQLPOINTER InfoV
     MADB_SET_NUM_VAL(SQLUINTEGER, InfoValuePtr, 0, StringLengthPtr);
     break;
   case SQL_CATALOG_LOCATION:
-    MADB_SET_NUM_VAL(SQLUINTEGER, InfoValuePtr, SQL_CL_START, StringLengthPtr);
+    MADB_SET_NUM_VAL(SQLUSMALLINT, InfoValuePtr, SQL_CL_START, StringLengthPtr);
     break;
   case SQL_CATALOG_NAME:
     /* Todo: MyODBC Driver has a DSN configuration for diabling catalog usage:
@@ -1207,7 +1209,7 @@ SQLRETURN MADB_DbcGetInfo(MADB_Dbc *Dbc, SQLUSMALLINT InfoType, SQLPOINTER InfoV
     break;
   }
   case SQL_GROUP_BY:
-    MADB_SET_NUM_VAL(SQLUINTEGER, InfoValuePtr, SQL_GB_NO_RELATION, StringLengthPtr);
+    MADB_SET_NUM_VAL(SQLUSMALLINT, InfoValuePtr, SQL_GB_NO_RELATION, StringLengthPtr);
     break;
   case SQL_IDENTIFIER_CASE:
     MADB_SET_NUM_VAL(SQLUINTEGER, InfoValuePtr, SQL_IC_MIXED, StringLengthPtr);
@@ -1603,9 +1605,13 @@ default:
     return Dbc->Error.ReturnValue;
   }
   if (isWChar && SLen)
+  {
     SLen*= sizeof(SQLWCHAR);
-  if (StringLengthPtr && SLen)
+  }
+  if (IsString_GetInfo_Type(InfoType) && StringLengthPtr)
+  {
     *StringLengthPtr= SLen;
+  }
   
   return SQL_SUCCESS;
 }
