@@ -736,7 +736,7 @@ SQLRETURN MADB_DescGetField(SQLHDESC DescriptorHandle,
     *((SQLPOINTER *)ValuePtr)= (SQLPOINTER)Desc->Header.BindOffsetPtr;
     break;
   case SQL_DESC_BIND_TYPE:
-    *((SQLINTEGER *)ValuePtr)= Desc->Header.BindType;
+    *((SQLULEN *)ValuePtr)= Desc->Header.BindType;
     break;
   case SQL_DESC_COUNT:
     *(SQLSMALLINT *)ValuePtr= Desc->Header.Count;
@@ -973,7 +973,9 @@ SQLRETURN MADB_DescSetField(SQLHDESC DescriptorHandle,
       break;
     }
   
-    if (DescRecord)
+    /* inUse is only used to check if column/parameter was bound or not. Thus we do not set it for each field, but only for those,
+       that make column/parameter "bound" */
+    if (DescRecord && (DescRecord->DataPtr != NULL || DescRecord->OctetLengthPtr != NULL || DescRecord->IndicatorPtr != NULL))
       DescRecord->inUse= 1;
   }
   return ret;
