@@ -1035,7 +1035,7 @@ int MADB_CharToSQLNumeric(char *buffer, MADB_Desc *Ard, MADB_DescRecord *ArdReco
       
       memcpy(digits + digits_count, dot + 1, digits_significant);
       digits_count+= digits_significant;
-
+      number->scale= (SQLSCHAR)digits_significant;
     } else 
     {
       char *start= p;
@@ -1133,7 +1133,7 @@ size_t MADB_SqlNumericToChar(SQL_NUMERIC_STRUCT *Numeric, char *Buffer, int *Err
   if (Numeric->scale > 0)
   {
     char tmp[38];
-    _snprintf(tmp,38, "%%%d.%df", Numeric->precision, Numeric->scale);
+    _snprintf(tmp,38, "%%.%df", Numeric->scale);
     _snprintf(Buffer, 38, tmp, Numerator / pow(10, Scale));
   }
   else
@@ -1289,3 +1289,66 @@ end:
   return Stmt->Error.ReturnValue;
 
 }
+
+
+BOOL MADB_IsNumericType(SQLSMALLINT ConciseType)
+{
+  switch (ConciseType)
+  {
+    case SQL_C_TINYINT:
+    case SQL_C_STINYINT:
+    case SQL_C_UTINYINT:
+    case SQL_C_SHORT:
+    case SQL_C_SSHORT:
+    case SQL_C_USHORT:
+    case SQL_C_LONG:
+    case SQL_C_SLONG:
+    case SQL_C_ULONG:
+    case SQL_C_UBIGINT:
+    case SQL_C_SBIGINT:
+    case SQL_BIGINT:
+    case SQL_C_DOUBLE:
+    case SQL_C_FLOAT:
+    case SQL_DECIMAL:
+      return TRUE;
+  }
+  return FALSE;
+}
+
+
+BOOL MADB_IsIntType(SQLSMALLINT ConciseType)
+{
+  switch (ConciseType)
+  {
+  case SQL_C_TINYINT:
+  case SQL_C_STINYINT:
+  case SQL_C_UTINYINT:
+  case SQL_C_SHORT:
+  case SQL_C_SSHORT:
+  case SQL_C_USHORT:
+  case SQL_C_LONG:
+  case SQL_C_SLONG:
+  case SQL_C_ULONG:
+  case SQL_C_UBIGINT:
+  case SQL_C_SBIGINT:
+  case SQL_BIGINT:
+    return TRUE;
+  }
+  return FALSE;
+}
+
+
+void MADB_InstallStmt(MADB_Stmt *Stmt)
+{
+  Stmt->stmt= Stmt->MultiStmts[Stmt->MultiStmtNr];
+
+  if (mysql_stmt_field_count(Stmt->stmt) == 0)
+  {
+    Stmt->AffectedRows= mysql_stmt_affected_rows(Stmt->stmt);
+  }
+  else
+  {
+    MADB_StmtResetResultStructures(Stmt);
+    MADB_DescSetIrdMetadata(Stmt, mysql_fetch_fields(FetchMetadata(Stmt)), mysql_stmt_field_count(Stmt->stmt));
+  }
+}
