@@ -308,8 +308,7 @@ struct st_ma_odbc_stmt
   MYSQL_RES                 *metadata;
   LIST                      ListItem;
   MADB_QUERY                *Tokens;
-  SQLINTEGER                ParamCount;
-  my_bool                   isMultiQuery;
+  SQLSMALLINT               ParamCount;
   enum MADB_DaeType         DataExecutionType;
   MYSQL_RES                 *DefaultsResult;
   int                       ArrayOffset;
@@ -318,7 +317,6 @@ struct st_ma_odbc_stmt
   MADB_DescRecord           *PutDataRec;
   MADB_Stmt                 *DaeStmt;
   char                      *StmtString;
-  char                      *NativeSql;
   MADB_Stmt                 *PositionedCursor;
   unsigned int              PositionedCommand;
   enum MADB_StmtState       State;
@@ -408,6 +406,7 @@ struct st_ma_odbc_connection
   char *TraceFile;
   SQLINTEGER TxnIsolation;
   SQLINTEGER CursorCount;
+  char ServerCapabilities;
 };
 
 typedef BOOL (__stdcall *PromptDSN)(HWND hwnd, MADB_Dsn *Dsn);
@@ -454,6 +453,7 @@ void            CloseClientCharset (Client_Charset *cc);
 #include <ma_result.h>
 #include <ma_driver.h>
 #include <ma_helper.h>
+#include <ma_server.h>
 
 /* SQLFunction calls inside MariaDB Connector/ODBC needs to be mapped,
  * on non Windows platforms these function calls will call the driver
