@@ -186,8 +186,8 @@ MYSQL_RES*   FetchMetadata          (MADB_Stmt *Stmt);
 
 /************** SQLColumns       *************/
 #define MADB_COLUMN_SIZE\
-    "CASE" \
-    "  WHEN DATA_TYPE = 'bit' THEN @ColSize:=CAST(((NUMERIC_PRECISION + 7) / 8) AS SIGNED) "\
+    "CAST(CASE" \
+    "  WHEN DATA_TYPE = 'bit' THEN @ColSize:=((NUMERIC_PRECISION + 7) / 8) "\
     "  WHEN DATA_TYPE in ('tinyint', 'smallint', 'year', 'mediumint', 'int',"\
                          "'bigint', 'decimal', 'double') THEN @ColSize:=NUMERIC_PRECISION "\
     "  WHEN DATA_TYPE = 'float' THEN @ColSize:=7"\
@@ -195,7 +195,7 @@ MYSQL_RES*   FetchMetadata          (MADB_Stmt *Stmt);
     "  WHEN DATA_TYPE='time' THEN @ColSize:=8"\
     "  WHEN DATA_TYPE in ('timestamp', 'datetime') THEN @ColSize:=19 "\
     "  ELSE @ColSize:=CHARACTER_MAXIMUM_LENGTH "\
-  "END "
+  "END AS SIGNED)"
 
 #define MADB_CATALOG_COLUMNSp1 "SELECT TABLE_SCHEMA AS TABLE_CAT, NULL AS TABLE_SCHEM, TABLE_NAME, COLUMN_NAME, "
 #define MADB_CATALOG_COLUMNSp3  ", UCASE(IF(COLUMN_TYPE LIKE '%%(%%)%%',  CONCAT(SUBSTRING(COLUMN_TYPE,1, LOCATE('(',COLUMN_TYPE) - 1 ), SUBSTRING(COLUMN_TYPE,1+locate(')',COLUMN_TYPE))), COLUMN_TYPE )) AS TYPE_NAME, "\
@@ -203,8 +203,11 @@ MYSQL_RES*   FetchMetadata          (MADB_Stmt *Stmt);
   MADB_TRANSFER_OCTET_LENGTH " AS BUFFER_LENGTH, "\
   "NUMERIC_SCALE DECIMAL_DIGITS, IF(CHARACTER_OCTET_LENGTH IS NOT NULL, NULL, 10) AS NUM_PREC_RADIX,"\
   "IF(DATA_TYPE='timestamp', 1, IF(IS_NULLABLE='YES',1,IF(EXTRA='auto_increment', 1, 0))) AS NULLABLE, "\
-  "COLUMN_COMMENT AS REMARKS,"\
-  "IF(COLLATION_NAME IS NOT NULL AND COLUMN_DEFAULT IS NOT NULL, CONCAT(CHAR(39), COLUMN_DEFAULT, CHAR(39)), COLUMN_DEFAULT) AS COLUMN_DEF,"\
+  "COLUMN_COMMENT AS REMARKS,"
+#define MADB_DEFAULT_COLUMN_OLD  "IF(COLLATION_NAME IS NOT NULL AND COLUMN_DEFAULT IS NOT NULL, CONCAT(CHAR(39), COLUMN_DEFAULT, CHAR(39)), COLUMN_DEFAULT)"
+#define MADB_DEFAULT_COLUMN_NEW  "COLUMN_DEFAULT"
+#define MADB_DEFAULT_COLUMN(DbcHndl) (MADB_ServerSupports(DbcHndl,MADB_ENCLOSES_COLUMN_DEF_WITH_QUOTES) ? MADB_DEFAULT_COLUMN_NEW : MADB_DEFAULT_COLUMN_OLD)
+#define MADB_CATALOG_COLUMNSp4 " AS COLUMN_DEF,"\
   "CASE"\
   "  WHEN DATA_TYPE = 'date' THEN " XSTR(SQL_DATETIME)\
   "  WHEN DATA_TYPE = 'time' THEN " XSTR(SQL_DATETIME)\
@@ -223,10 +226,6 @@ MYSQL_RES*   FetchMetadata          (MADB_Stmt *Stmt);
   "ORDINAL_POSITION,"\
   "IF(DATA_TYPE='timestamp', 'YES', IF(IS_NULLABLE='YES','YES',IF(EXTRA='auto_increment', 'YES', 'NO'))) AS IS_NULLABLE FROM INFORMATION_SCHEMA.COLUMNS WHERE "
 
-#define MADB_CATALOG_COLUMNS_ODBC3 MADB_CATALOG_COLUMNSp1 MADB_SQL_DATATYPE_ODBC3 MADB_CATALOG_COLUMNSp3
-#define MADB_CATALOG_COLUMNS_ODBC2 MADB_CATALOG_COLUMNSp1 MADB_SQL_DATATYPE_ODBC2 MADB_CATALOG_COLUMNSp3
-#define MADB_CATALOG_COLUMNS(StmtHndl) (StmtHndl->Connection->Environment->OdbcVersion >= SQL_OV_ODBC3 ?\
-                                        MADB_CATALOG_COLUMNS_ODBC3 : MADB_CATALOG_COLUMNS_ODBC2)
 /************** End of SQLColumns ************/
 
 /************** SQLProcedureColumns **********/
